@@ -42,12 +42,12 @@ extern "C" {
 @class NSMutableArray;
 @class NSMutableDictionary;
 
-#if OS_API_VERSION(100500,GS_API_LATEST) 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_5,GS_API_LATEST) 
 enum {
   NSBundleExecutableArchitectureI386      = 0x00000007,
   NSBundleExecutableArchitecturePPC       = 0x00000012,
   NSBundleExecutableArchitecturePPC64     = 0x01000012,
-  NSBundleExecutableArchitectureX86_64    = 0x01000007,
+  NSBundleExecutableArchitectureX86_64    = 0x01000007
 };
 #endif
 
@@ -184,15 +184,18 @@ GS_EXPORT NSString* const NSLoadedClasses;
  * not readable, return nil.  If you want the main bundle of an
  * application or a tool, it's better if you use +mainBundle.  */
 + (NSBundle*) bundleWithPath: (NSString*)path;
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_6,GS_API_LATEST) 
++ (NSBundle*) bundleWithURL: (NSURL*)url;
+#endif
 
 /**
   Returns an absolute path for a resource name with the extension
-  ext in the specified bundlePath.  See also
+  in the specified bundlePath.  See also
   -pathForResource:ofType:inDirectory: for more information on
   searching a bundle.  
  */
 + (NSString*) pathForResource: (NSString*)name
-		       ofType: (NSString*)ext
+		       ofType: (NSString*)extension
 		  inDirectory: (NSString*)bundlePath;
 
 /**
@@ -200,10 +203,17 @@ GS_EXPORT NSString* const NSLoadedClasses;
   so this method behaves exactly like +pathForResource:ofType:inDirectory:.
  */
 + (NSString*) pathForResource: (NSString*)name
-		       ofType: (NSString*)ext
+		       ofType: (NSString*)extension
 		  inDirectory: (NSString*)bundlePath
 		  withVersion: (int)version;
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_6,GS_API_LATEST) 
++ (NSURL*) URLForResource: (NSString*)name
+            withExtension: (NSString*)extension
+             subdirectory: (NSString*)subpath
+          inBundleWithURL: (NSURL*)bundleURL;
+#endif
+
 /** <init />
  * Init the bundle for reading resources from path.<br />
  * The MacOS-X documentation says that the path must be a full path to
@@ -226,9 +236,17 @@ GS_EXPORT NSString* const NSLoadedClasses;
  */
 - (id) initWithPath: (NSString*)path;
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_6,GS_API_LATEST) 
+- (id) initWithURL: (NSURL*)url;
+#endif
+
 /** Return the path to the bundle - an absolute path.  */
 - (NSString*) bundlePath;
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_6,GS_API_LATEST) 
+- (NSURL*) bundleURL;
+#endif
+
 /** Returns the class in the bundle with the given name. If no class
     of this name exists in the bundle, then Nil is returned.
  */
@@ -268,7 +286,7 @@ GS_EXPORT NSString* const NSLoadedClasses;
 
 /**
   <p>
-   Returns an absolute path for a resource name with the extension ext
+   Returns an absolute path for a resource name with the extension
    in the specified bundlePath. Directories in the bundle are searched
    in the following order:
    </p>
@@ -283,41 +301,46 @@ GS_EXPORT NSString* const NSLoadedClasses;
    the bundle.
    </p>
    <p>
-   If ext is nil or empty, then the first file exactly matching name
+   If extension is nil or empty, then the first file exactly matching name
    (ie with no extension) is returned.
    </p>
 */
 - (NSString*) pathForResource: (NSString*)name
-		       ofType: (NSString*)ext
+		       ofType: (NSString*)extension
 		  inDirectory: (NSString*)subPath;
 
 /**
-   Returns an absolute path for a resource name with the extension ext
+   Returns an absolute path for a resource name with the extension
    in the receivers bundle path. 
    See -pathForResource:ofType:inDirectory:.
  */
 - (NSString*) pathForResource: (NSString*)name
-		       ofType: (NSString*)ext;
+		       ofType: (NSString*)extension;
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_6,GS_API_LATEST) 
+- (NSURL*) URLForResource: (NSString*)name
+            withExtension: (NSString*)extension;
+- (NSURL*) URLForResource: (NSString*)name
+            withExtension: (NSString*)extension
+             subdirectory: (NSString*)subpath;
+- (NSURL*) URLForResource: (NSString*)name 
+            withExtension: (NSString*)extension
+             subdirectory: (NSString*)subpath
+             localization: (NSString*)localizationName;
+#endif
 
 /**
-   <p>Returns the value for the key found in the strings file tableName, or
-   Localizable.strings if tableName is nil.</p>
-
-   <p>If the user default <code>NSShowNonLocalizedStrings</code> is set, the
-   value of the key will be returned as an uppercase string rather than any
-   localized equivalent found.  This can be useful during development to check
-   where a given string in the UI is "coming from".</p>
+ * <p>Returns the value for the key found in the strings file tableName, or
+ * Localizable.strings if tableName is nil.
+ * </p>
+ * <p>If the user default <code>NSShowNonLocalizedStrings</code> is set, the
+ * value of the key will be returned as an uppercase string rather than any
+ * localized equivalent found.  This can be useful during development to check
+ * where a given string in the UI is "coming from".</p>
  */
-#ifdef __clang__
-- (NSString*) localizedStringForKey: (NSString*)key
-			      value: (NSString*)value
-			      table: (NSString*)tableName
-				  __attribute__((format_arg(1)));
-#else
 - (NSString*) localizedStringForKey: (NSString*)key
 			      value: (NSString*)value
 			      table: (NSString*)tableName;
-#endif
 
 /** Returns the absolute path to the resources directory of the bundle.  */
 - (NSString*) resourcePath;
@@ -325,6 +348,22 @@ GS_EXPORT NSString* const NSLoadedClasses;
 /** Returns the full path to the plug-in subdirectory of the bundle.  */
 - (NSString *) builtInPlugInsPath;
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_6,GS_API_LATEST) 
+/** Returns the full path to the plug-in subdirectory of the bundle.  */
+- (NSURL *) builtInPlugInsURL;
+#endif
+
+/** Returns the full path to the private frameworks subdirectory of the bundle.  */
+- (NSString *) privateFrameworksPath;
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_6,GS_API_LATEST) 
+/** Returns the full path to the private frameworks subdirectory of the bundle.  */
+- (NSURL *) privateFrameworksURL;
+#endif
+
+
+
+
 /** Returns the bundle identifier, as defined by the CFBundleIdentifier
     key in the infoDictionary */
 - (NSString *) bundleIdentifier;
@@ -350,7 +389,7 @@ GS_EXPORT NSString* const NSLoadedClasses;
 + (NSArray *) preferredLocalizationsFromArray: (NSArray *)localizationsArray 
 			       forPreferences: (NSArray *)preferencesArray;
 
-#if OS_API_VERSION(100200,GS_API_LATEST) 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_2,GS_API_LATEST) 
 /**
  * Returns a boolean indicating whether code for the bundle has been loaded.
  */
@@ -374,14 +413,14 @@ GS_EXPORT NSString* const NSLoadedClasses;
  * resources.
  */
 - (NSString*) pathForResource: (NSString*)name
-		       ofType: (NSString*)ext
+		       ofType: (NSString*)extension
 		  inDirectory: (NSString*)subPath
 	      forLocalization: (NSString*)localizationName;
 
 /** Returns the info property list associated with the bundle. */
 - (NSDictionary*) infoDictionary;
 
-#if OS_API_VERSION(100200,GS_API_LATEST) 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_2,GS_API_LATEST) 
 /** Returns a localized info property list based on the preferred
  *  localization or the most appropriate localization if the preferred
  *  one cannot be found.
@@ -413,7 +452,7 @@ GS_EXPORT NSString* const NSLoadedClasses;
  */
 - (BOOL) load;
 
-#if OS_API_VERSION(100200,GS_API_LATEST) 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_2,GS_API_LATEST) 
 /** * Not implemented
  */
 - (BOOL) unload;
@@ -421,9 +460,21 @@ GS_EXPORT NSString* const NSLoadedClasses;
 
 /** Returns the path to the executable code in the bundle */
 - (NSString *) executablePath;
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_6,GS_API_LATEST)
+- (NSURL *) executableURL;
 #endif
 
-#if OS_API_VERSION(100500,GS_API_LATEST) 
+- (NSString *) pathForAuxiliaryExecutable: (NSString *) executableName;
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_6,GS_API_LATEST)
+- (NSURL *)URLForAuxiliaryExecutable: (NSString *) executableName;
+#endif
+
+
+#endif
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_5,GS_API_LATEST) 
 /** Not implemented */
 - (NSArray *) executableArchitectures;
 /** Not implemented */
@@ -481,7 +532,7 @@ GS_EXPORT NSString* const NSLoadedClasses;
 
 /** Find a resource in the "Library" directory. */
 + (NSString*) pathForLibraryResource: (NSString*)name
-			      ofType: (NSString*)ext
+			      ofType: (NSString*)extension
 			 inDirectory: (NSString*)bundlePath;
 
 @end
