@@ -43,30 +43,33 @@
 #  define	NO_GNUSTEP	1
 #endif
 
-/*
- * For MacOS-X compatibility, we define the MacOS-X version constants and
- * we allow MAC_OS_X_VERSION_MIN_ALLOWED or MAC_OS_X_VERSION_MAX_ALLOWED
- * instead of GS_OPENSTEP_V
+/* Define the GS_OSX_ADJUST() macro to adjust OSX style version macros
+ * to GNUstep style version macros.
  */
+#define	GS_OSX_ADJUST(V) ((V) >= 10000 ? (V) : ((V)/100*10000 + (V)%100*10))
 
-#ifndef	MAC_OS_X_VERSION_10_0
-#define	MAC_OS_X_VERSION_10_0	100000
-#define	MAC_OS_X_VERSION_10_1	100100
-#define	MAC_OS_X_VERSION_10_2	100200
-#define	MAC_OS_X_VERSION_10_3	100300
-#define	MAC_OS_X_VERSION_10_4	100400
-#define	MAC_OS_X_VERSION_10_5	100500
-#define	MAC_OS_X_VERSION_10_6	100600
+/* Define OSX compatibility version macros if necessary.
+ */
+#if     !defined(MAC_OS_X_VERSION_10_0)
+#define	MAC_OS_X_VERSION_10_0	1000
+#define	MAC_OS_X_VERSION_10_1	1010
+#define	MAC_OS_X_VERSION_10_2	1020
+#define	MAC_OS_X_VERSION_10_3	1030
+#define	MAC_OS_X_VERSION_10_4	1040
+#define	MAC_OS_X_VERSION_10_5	1050
+#define	MAC_OS_X_VERSION_10_6	1060
+#define	MAC_OS_X_VERSION_10_7	1070
+#define	MAC_OS_X_VERSION_10_8	1080
+#define	MAC_OS_X_VERSION_10_9	1090
 #endif	/* MAC_OS_X_VERSION_10_0 */
 
+/* Allow MAC_OS_X_VERSION_MAX_ALLOWED to be used in place of GS_OPENSTEP_V
+ * if GS_OPENSTEP_V is not defined.
+ */
 #ifndef	GS_OPENSTEP_V
-#ifdef	MAC_OS_X_VERSION_MIN_ALLOWED
-#define	GS_OPENSTEP_V	MAC_OS_X_VERSION_MIN_ALLOWED
-#else
 #ifdef	MAC_OS_X_VERSION_MAX_ALLOWED
-#define	GS_OPENSTEP_V	MAC_OS_X_VERSION_MAX_ALLOWED
+#define	GS_OPENSTEP_V	GS_OSX_ADJUST(MAC_OS_X_VERSION_MAX_ALLOWED)
 #endif	/* MAC_OS_X_VERSION_MAX_ALLOWED */
-#endif	/* MAC_OS_X_VERSION_MIN_ALLOWED */
 #endif	/* GS_OPENSTEP_V */
 
 /*
@@ -91,12 +94,9 @@
  * two digits are the major version number, the second two are the minor
  * version number and the last two are the subminor number (all left padded
  * with a zero where necessary).  However, for convenience you can also
- * use any of several predefined constants ...
+ * use the predefined constants ...
  * <ref type="macro" id="GS_API_NONE">GS_API_NONE</ref>,
  * <ref type="macro" id="GS_API_LATEST">GS_API_LATEST</ref>,
- * <ref type="macro" id="GS_API_OSSPEC">GS_API_OSSPEC</ref>,
- * <ref type="macro" id="GS_API_OPENSTEP">GS_API_OPENSTEP</ref>,
- * <ref type="macro" id="GS_API_MACOSX">GS_API_MACOSX</ref>
  * </p>
  * <p>Also see <ref type="macro" id="OS_API_VERSION">OS_API_VERSION</ref>
  * </p>
@@ -133,9 +133,27 @@
  * </p>
  * <p>Also see <ref type="macro" id="GS_API_VERSION">GS_API_VERSION</ref>
  * </p>
+ * <p>For OSX compatibility, this macro also supports the use of Apple's
+ * symbolic constants for version numbering.  Their contants are currently
+ * four digit values (two digits for the major version, one for the minor,
+ * and one for the subminor). 
+ * </p>
+ * <p>The Apple compatibility version macros are currently:
+ * <ref type="macro" id="MAC_OS_X_VERSION_10_0">MAC_OS_X_VERSION_10_0</ref>,
+ * <ref type="macro" id="MAC_OS_X_VERSION_10_1">MAC_OS_X_VERSION_10_1</ref>,
+ * <ref type="macro" id="MAC_OS_X_VERSION_10_2">MAC_OS_X_VERSION_10_2</ref>,
+ * <ref type="macro" id="MAC_OS_X_VERSION_10_3">MAC_OS_X_VERSION_10_3</ref>,
+ * <ref type="macro" id="MAC_OS_X_VERSION_10_4">MAC_OS_X_VERSION_10_4</ref>,
+ * <ref type="macro" id="MAC_OS_X_VERSION_10_5">MAC_OS_X_VERSION_10_5</ref>,
+ * <ref type="macro" id="MAC_OS_X_VERSION_10_6">MAC_OS_X_VERSION_10_6</ref>,
+ * <ref type="macro" id="MAC_OS_X_VERSION_10_7">MAC_OS_X_VERSION_10_7</ref>,
+ * <ref type="macro" id="MAC_OS_X_VERSION_10_8">MAC_OS_X_VERSION_10_8</ref>
+ * <ref type="macro" id="MAC_OS_X_VERSION_10_9">MAC_OS_X_VERSION_10_9</ref>
+ * </p>
  */
 #define	OS_API_VERSION(ADD,REM) \
-  (!defined(GS_OPENSTEP_V) || (GS_OPENSTEP_V >= ADD && GS_OPENSTEP_V < REM))
+  (!defined(GS_OPENSTEP_V) \
+  || (GS_OPENSTEP_V>=GS_OSX_ADJUST(ADD) && GS_OPENSTEP_V<GS_OSX_ADJUST(REM)))
 
 /**
  * A constant which is the lowest possible version number (0) so that
@@ -186,6 +204,14 @@
  */
 #define	GS_API_MACOSX	100000
 
+/* Allow OSX code comparing MAC_OS_X_VERSION_MAX_ALLOWED with a specific
+ * version to see if that version is allowed, to always have it allowed
+ * on GNUstep.
+ */
+#ifndef	MAC_OS_X_VERSION_MAX_ALLOWED
+#define	MAC_OS_X_VERSION_MAX_ALLOWED    GS_API_LATEST
+#endif  /* MAC_OS_X_VERSION_MAX_ALLOWED */
+
 
 #if	defined(GNUSTEP_BASE_INTERNAL)
 #import "GNUstepBase/GSConfig.h"
@@ -313,7 +339,7 @@ static inline void gs_consumed(id NS_CONSUMED GS_UNUSED_ARG o) { return; }
  */
 #if __has_feature(blocks)
 #  if	OBJC2RUNTIME
-#    if defined(_APPLE_)
+#    if defined(__APPLE__)
 #      include <Block.h>
 #    else
 #      include <objc/blocks_runtime.h>
@@ -372,7 +398,8 @@ static inline void gs_consumed(id NS_CONSUMED GS_UNUSED_ARG o) { return; }
 #  define NS_FORMAT_ARGUMENT(F,A) 
 #endif
 
-#if __GNUC__*10+__GNUC_MINOR__ >= 42
+// FIXME ... what version of gcc?
+#if __clang__
 #  define NS_FORMAT_FUNCTION(F,A) __attribute__((format(__NSString__, F, A)))
 #else
 #  define NS_FORMAT_FUNCTION(F,A) 
